"use strict";
var system = require('system');

function loadAndScreenshotPage() {
  var inputLine = system.stdin.readLine();
  if (inputLine == null || inputLine == "" || inputLine == "exit") {
    phantom.exit(0);
  }
  var page = require("webpage").create();
  var settings = JSON.parse(inputLine);

  page.viewportSize = {
    width: settings.width,
    height: settings.height
  };
  page.zoomFactor = settings.zoom;

  var counter = 0; //counter calculates all pending http requests; this allows to determine when all requests are ready (i.e. webpage is loaded)
  var requestUrls = []; // keep track that response urls correspond with requested urls
  var waitingInProgress = false; //needed so that a new interval is not started when previous is ongoing (see setInterval below)
  var startTime = new Date();
  page.onResourceRequested = function(request) { //increase counter when a http request is sent
    counter++;
    requestUrls.push(request.url);
  };
  page.onResourceReceived = function(response) { //descrease counter when a http response is received
    var itemIndex = requestUrls.indexOf(response.url);
    if (itemIndex > -1) {
	  requestUrls.splice(itemIndex, 1);
	  counter--;
    }
  };
  page.open(settings.pageUrl, function() {
    setInterval(function() { // poll every 10ms, and check when all http requests are ready 
      if ((startTime + 0) < (new Date() - settings.timeout)) counter = 0; //when true, timeout has been reached 
	  if (counter <= 0 && !waitingInProgress) {
	    waitingInProgress = true;
	    setTimeout(function() { // wait the rendering delay, until take the screenshot
		  if (counter <= 0) {
            var base64Data = page.renderBase64("PNG");
            system.stdout.write("imagedata:" + base64Data + "\n");
		    page.close();
		    loadAndScreenshotPage();
		  } else {
		    waitingInProgress = false;	
		  }
	    }, settings.renderingDelay);
	  }
    }, 10);
  });
  
}

loadAndScreenshotPage();